# gathers

[![CI](https://github.com/kemingy/gathers/actions/workflows/check.yml/badge.svg)](https://github.com/kemingy/gathers/actions/workflows/check.yml)
[![crates.io](https://img.shields.io/crates/v/gathers.svg)](https://crates.io/crates/gathers)
[![docs.rs](https://docs.rs/gathers/badge.svg)](https://docs.rs/gathers)

Clustering algorithm implementation:

- [x] K-means
- [x] PyO3 binding
- [x] RaBitQ assignment
- [x] Parallel with Rayon
- [ ] mini batch K-means
- [ ] Hierarchical K-means
